package com.vizitsolutions.demo;

/**
 * Simple example table model with several columns ensuring that the table will scroll
 * horizontally.
 */

import com.vizitsolutions.identitytable.IdentityTableModel;

/**
 * @author  Alex Kluge
 * @version $Revision: $, $Date: $
 */
public class PersonnelIdentityTableModel extends IdentityTableModel
{
    final String[] columnNames =
    {
        "Name",
        "Department",
        "Position",
        "Manager",
        "Office",
        "Office Phone",
        "Years of Service",
        "Salary",
        "Home Address",
        "Home Phone",
        "Cell Phone"
    };
    
    final Class[] columnTypes =
    {
        String.class,
        String.class,
        String.class,
        String.class,
        String.class,
        String.class,
        String.class,
        String.class,
        String.class,
        String.class,
        String.class
    };
    
    final boolean[] isColumnEditable =
    {
        false,
        true,
        true,
        true,
        true,
        true,
        true,
        true,
        true,
        true,
        true
    };
    
    public static final int NONE               = -1;
    public static final int NAME               = 0;
    public static final int DEPARTMENT         = 1;
    public static final int POSITION           = 2;
    public static final int MANAGER            = 3;
    public static final int OFFICE             = 4;
    public static final int OFFICE_PHONE       = 5;
    public static final int YEARS_OF_SERVICE   = 6;
    public static final int SALARY             = 7;
    public static final int HOME_ADDRESS       = 8;
    public static final int HOME_PHONE         = 9;
    public static final int CELL_PHONE         = 10;
    
    // The set of people
    String[][] personnel = {{"John Q Public",   "Customer Support",     "Technician",                   "Kelly Smith",  "101C", "555-1111", "2", "45000",  "127 Main",               "555-1742", "555-1975"},
                            {"Kelvin Lanny" ,   "Marketing",            "Account coordinator",          "Mickey Mouse", "101D", "555-1112", "1", "65000",  "475 East",               "555-4226", "555-5979"},
                            {"Valorie Alwilda", "Business Development", "Campaign coordinator",         "Mickey Mouse", "101E", "555-1113", "1", "55000",  "225 F St.",              "555-4379", "555-4127"},
                            {"Joe Random",      "Product Development",  "Programmer",                   "Rob Ratcliff", "101F", "555-1114", "1", "65000",  "4257 Forrest Ave",       "555-1145", "555-2727"},
                            {"Alex Kluge",      "Product Development",  "Software engineer",            "",             "101G", "555-1115", "3", "90000",  "5129 Burnet",            "555-8630", "555-1492"},
                            {"Rob Ratcliff",    "Product Development",  "Software engineer",            "",             "101H", "555-1116", "3", "90000",  "2275 Westlake",          "555-0479", "555-1875"},
                            {"Kathy Schmidt",   "Training",             "Training coordinator",         "",             "101I", "555-1117", "2", "50000",  "1229 Spicewood Springs", "555-5643", "555-1962"},
                            {"Mickey Mouse",    "Entertainment",        "He's a mouse",                 "Walt",         "101J", "555-1118", "3", "Cheese", "Hole in the wall",       "555-CHSE", ""},
                            {"Kelly Smith",     "Project Manageet",     "Product manager",              "",             "101K", "555-1119", "1", "85000",  "100 Lost Creek",         "555-4079", "555-4275"},
                            {"Chris Born",      "IT",                   "Operating systems specialist", "Kelly Smith",  "101L", "555-1110", "1", "55000",  "19276 Guadalupe",        "555-9579", "555-1097"}};
    
    /**
     * Creates a new instance, with the default 1 identity column count.
     */
    public PersonnelIdentityTableModel(){}
    
    public int getColumnCount()
    {
        return columnNames.length;
    }

    public int getRowCount()
    {
        if(personnel == null)
        {
            return 0;
        }
        return personnel.length;
    }

    public String getColumnName(int col)
    {
        return columnNames[col];
    }

    public Object getValueAt(int row, int col)
    {
        return personnel[row][col];
    }

    /**
     * JTable uses this method to determine the default renderer/
     * editor for each cell.  Otherwise JTable always uses the
     * default cell renderer.
     */
    public Class getColumnClass(int column)
    {
        return columnTypes[column];
    }

    public boolean isCellEditable(int row, int column)
    {
        return isColumnEditable[column];
    }

    /**
     * When the cells are edited, this method is called to
     * set the new values.
     */
    public void setValueAt(Object value, int row, int column)
    {
        personnel[row][column] = (String)value;
        fireTableCellUpdated(row, column);
    }
}
