package com.vizitsolutions.identitytable;

import javax.swing.table.AbstractTableModel;

/**
 * <p>$Id$</p>
 * 
 * <p>
 * An extension of the AbstractTableModel to include the concept of a
 * horizontally fixed set of columns that identify the contents of a row.
 * </p>
 * 
 * @author akluge
 * @version $Revision$, $Date$
 */
public abstract class IdentityTableModel extends AbstractTableModel
{
    /**
     * The number of columns to keep fixed in place
     * when horizontally scrolling the table. Defaults
     * to 1.
     */
    protected int identityColumnCount = 1;
    
    /**
     * Get the number of columns that identify the contents of each row. These
     * columns remain fixed in place when the table scrolls horizontally.
     * 
     * @return An int giving the number of columns that identify the contents
     *         of each row.
     */
    public int getIdentityColumnCount()
    {
        return identityColumnCount;
    }
    
    /**
     * Set the number of rows that identify the contents of each row. These
     * columns remain fixed in place when the table scrolls horizontally.
     * 
     * @param identityColumnCount An int giving the number of rows that
     *                            identify the contents of each row.
     */
    public void setIdentityColumnCount(int identityColumnCount)
    {
        this.identityColumnCount = identityColumnCount;
    }
}
