
package com.vizitsolutions.identitytable;

import javax.swing.AbstractAction;
import javax.swing.Action;
import java.awt.event.ActionEvent;
import javax.swing.JTable;

/**
 * <p>$Id: $</p>
 *
 * Handle events by delegating the handling to the appropriate action in the
 * main table.
 * 
 * @author  Alex Kluge
 * @version $Revision: $, $Date: $
 */
public class RowHeaderActionProxy extends AbstractAction
{
    JTable mainTable;
    Action action;
    
    /**
     * Creates a new instance of RowHeaderActionProxy.
     * 
     * @param mainTable The main table, which correctly handles the action.
     * @param action    The action defined on the main table, used to delegate
     *                  the action from the row header to the main table.
     */
    public RowHeaderActionProxy(JTable mainTable, Action action)
    {
        this.mainTable = mainTable;
        this.action    = action;
    }
    
    /**
     * Triggered when the action is performed on the row header. The source of
     * the event is set to the main table, then the main tables action is invoked.
     * 
     * @param event The event that triggered the action.
     */
    public void actionPerformed(ActionEvent event)
    {
        // make the action look like it happened in the main table.
        event.setSource(mainTable);
        action.actionPerformed(event);
    }
}

